==> open-xchange-dav_7.10.1.orig.tar.bz2: open-xchange-dav-7.10.1/com.openexchange.caldav/src/com/openexchange/caldav/action/CalDAVPUTAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.caldav.action;

import javax.servlet.http.HttpServletResponse;
import com.openexchange.caldav.GroupwareCaldavFactory;
import com.openexchange.dav.DAVProtocol;
import com.openexchange.dav.PreconditionException;
import com.openexchange.dav.actions.PUTAction;
import com.openexchange.exception.OXException;
import com.openexchange.webdav.action.WebdavRequest;
import com.openexchange.webdav.protocol.WebdavProtocolException;

/**
 * {@link CalDAVPUTAction}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.10.0
 */
public class CalDAVPUTAction extends PUTAction {

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(CalDAVPUTAction.class);

    private final GroupwareCaldavFactory factory;

    /**
     * Initializes a new {@link CalDAVPUTAction}.
     *
     * @param factory The underlying factory
     */
    public CalDAVPUTAction(GroupwareCaldavFactory factory) {
        super(factory.getProtocol());
        this.factory = factory;
    }

    @Override
    protected WebdavProtocolException getSizeExceeded(WebdavRequest request) {
        return new PreconditionException(DAVProtocol.CAL_NS.getURI(), "max-resource-size", HttpServletResponse.SC_FORBIDDEN);
    }

    @Override
    protected long getMaxSize() {
        long defaultValue = 10 * 1024 * 1024; // 10M
        try {
            return Long.parseLong(factory.getConfigValue("MAX_UPLOAD_SIZE", String.valueOf(defaultValue)));
        } catch (NumberFormatException | OXException e) {
            LOG.warn("Error reading value for \"MAX_UPLOAD_SIZE\", falling back to {}.", defaultValue, e);
            return defaultValue;
        }
    }

    @Override
    protected boolean includeResponseETag() {
        return false;
    }

}

==> open-xchange-dav_7.10.3.orig.tar.bz2: open-xchange-dav-7.10.3/com.openexchange.caldav/src/com/openexchange/caldav/action/CalDAVPUTAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.caldav.action;

import javax.servlet.http.HttpServletResponse;
import com.openexchange.caldav.GroupwareCaldavFactory;
import com.openexchange.dav.DAVProtocol;
import com.openexchange.dav.PreconditionException;
import com.openexchange.dav.actions.PUTAction;
import com.openexchange.exception.OXException;
import com.openexchange.webdav.action.WebdavRequest;
import com.openexchange.webdav.protocol.WebdavProtocolException;

/**
 * {@link CalDAVPUTAction}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.10.0
 */
public class CalDAVPUTAction extends PUTAction {

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(CalDAVPUTAction.class);

    private final GroupwareCaldavFactory factory;

    /**
     * Initializes a new {@link CalDAVPUTAction}.
     *
     * @param factory The underlying factory
     */
    public CalDAVPUTAction(GroupwareCaldavFactory factory) {
        super(factory.getProtocol());
        this.factory = factory;
    }

    @Override
    protected WebdavProtocolException getSizeExceeded(WebdavRequest request) {
        return new PreconditionException(DAVProtocol.CAL_NS.getURI(), "max-resource-size", HttpServletResponse.SC_FORBIDDEN);
    }

    @Override
    protected long getMaxSize() {
        long defaultValue = 10 * 1024 * 1024; // 10M
        try {
            return Long.parseLong(factory.getConfigValue("MAX_UPLOAD_SIZE", String.valueOf(defaultValue)));
        } catch (NumberFormatException | OXException e) {
            LOG.warn("Error reading value for \"MAX_UPLOAD_SIZE\", falling back to {}.", Long.valueOf(defaultValue), e);
            return defaultValue;
        }
    }

    @Override
    protected boolean includeResponseETag() {
        return false;
    }

}
